<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Language;
use Illuminate\Support\Facades\Validator;

class LanguageController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $language = Language::get();
         return view('admin.languages.index')->with('language', $language);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request){
        $rules =
            [
              'name'=>"required|unique:languages,name",
              'abbr' =>'required'
            ];
        $message=
            [
               'name.required' => 'Name is required',
               'abbr.required' =>'Abbrevation is required',
            ];
            $validator = Validator::make($request->all(), $rules, $message);
        
            if ($validator->fails()) {
                return back()->withInput()->withErrors($validator->getMessageBag());
            }
        $lan =new Language;
        $input=$request->all();
        $input['is_active'] = 1;
        $lan->fill($input);
        $lan->save();
        return back()->with("success", "Inserted Successfully");

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules =
            [
              'abbr'=>"required|unique:languages,name",
              'name' =>'required',
            ];
        $message=
            [
               'abbr.required' => 'Abbrivation is required',
               'name.required' =>'Name is required',
            ];
        

        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator->getMessageBag());
        }
        $lan=Language::findorfail($id);
        $lan->name = $request->name;
        $lan->des =$request->des;
        $lan->update();
        return back()->with("success", "Updated Successfully");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $lan=Language::findorfail($id);
        $lan->delete();
        return back()->with("success", "Deleted Successfully");
    }
}
